"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseVuepressFileHeader = exports.parseComment = void 0;
/*
 * @vuepress
 * ---
 * headline: lib/comment-parser.ts
 * ---
 */
var front_matter_1 = __importDefault(require("front-matter"));
/**
 * Search in file for @vuepress comment
 * @param fileContent {string} content of given file
 * @returns {object} object of found frontmatter data
 */
var parseComment = function (fileContent) {
    try {
        var allCommentBlocks = fileContent.match(/\/\*[\s\S]*?\*\/|([^:]|^)\/\/.*$/g);
        var vuepressBlock = allCommentBlocks === null || allCommentBlocks === void 0 ? void 0 : allCommentBlocks.filter(function (block) {
            return block.split('\n').filter(function (line) { return line.indexOf('@vuepress') >= 0; }).length;
        })[0];
        if (!vuepressBlock) {
            return {
                frontmatter: null,
                attributes: null
            };
        }
        return (0, front_matter_1.default)(vuepressBlock
            .replace(/\n /g, '\n')
            .replace('/*', '')
            .replace('*/', '')
            .replace(/@vuepress/g, '')
            .replace(/\*\s?/g, '')
            .trim());
    }
    catch (e) {
        return {
            frontmatter: null,
            attributes: null
        };
    }
};
exports.parseComment = parseComment;
/**
 * Helper function to get header as structured markdown
 * @param content {string} file content
 * @param file {object} file object
 * @returns {string} markdown header
 */
var parseVuepressFileHeader = function (content, file) {
    var _a = (0, exports.parseComment)(content), frontmatter = _a.frontmatter, attributes = _a.attributes;
    var fileContent = '---\n';
    fileContent += !(attributes === null || attributes === void 0 ? void 0 : attributes.title) ? "title: " + file.name : '';
    if (frontmatter) {
        fileContent += !(attributes === null || attributes === void 0 ? void 0 : attributes.title) ? '\n' : '';
        fileContent += "" + frontmatter;
    }
    fileContent += '\n---\n';
    if ((attributes === null || attributes === void 0 ? void 0 : attributes.title) || file.ext !== '.vue') {
        var headline = file.name;
        if (attributes === null || attributes === void 0 ? void 0 : attributes.headline) {
            headline = attributes.headline;
        }
        else if (attributes === null || attributes === void 0 ? void 0 : attributes.title) {
            headline = attributes.title;
        }
        fileContent += "\n# " + headline + "\n\n";
    }
    return fileContent;
};
exports.parseVuepressFileHeader = parseVuepressFileHeader;
